Add a "Force" option for mkfs.
Display the output from mkfs.xfs in a user message if mkfs.xfs fails.

--- evms-2.3.2a/plugins/xfs/fs_xfs.c	22 Mar 2004 16:54:10 -0000	1.33
+++ evms-2.3.2b/plugins/xfs/fs_xfs.c	29 Apr 2004 19:03:53 -0000	1.34
@@ -923,6 +923,16 @@
 		option[MKFS_SETLOGSIZE_INDEX].constraint.range->increment.r32 = 0.1;
 		option[MKFS_SETLOGSIZE_INDEX].value.r32 = 4.6;
 
+		/* Force option */
+		SET_STRING(option[MKFS_FORCE_INDEX].name, "force");
+		SET_STRING(option[MKFS_FORCE_INDEX].title, "Force");
+		SET_STRING(option[MKFS_FORCE_INDEX].tip, "Force the mkfs even if XFS thinks the volume has an existing filesystem");
+		option[MKFS_FORCE_INDEX].type = EVMS_Type_Boolean;
+		option[MKFS_FORCE_INDEX].unit = EVMS_Unit_None;
+		option[MKFS_FORCE_INDEX].flags = EVMS_OPTION_FLAGS_NOT_REQUIRED;
+		option[MKFS_FORCE_INDEX].constraint_type = EVMS_Collection_None;
+		option[MKFS_FORCE_INDEX].value.b = FALSE;
+
 		context->min_selected_objects = 1;
 		context->max_selected_objects = 1;
 		break;
@@ -1013,6 +1023,10 @@
 			option[index].value.r32 = value->r32;
 			break;
 
+		case MKFS_FORCE_INDEX:
+			option[index].value.b = value->b;
+			break;
+
 		default:
 			break;
 		}
--- evms-2.3.2a/plugins/xfs/fsimxfs.h	20 Feb 2004 15:44:52 -0000	1.12
+++ evms-2.3.2b/plugins/xfs/fsimxfs.h	29 Apr 2004 19:03:53 -0000	1.13
@@ -38,8 +38,9 @@
 #define MKFS_SETVOL_INDEX		0
 #define MKFS_JOURNAL_VOL_INDEX		1
 #define MKFS_SETLOGSIZE_INDEX		2
-#define MKFS_XFS_OPTIONS_COUNT		3
-#define MKFS_XFS_OPTIONS_COUNT_TOTAL	10
+#define MKFS_FORCE_INDEX		3
+#define MKFS_XFS_OPTIONS_COUNT		4
+#define MKFS_XFS_OPTIONS_COUNT_TOTAL	11
 
 /* fsck exit codes */
 #define FSCK_OK				0
--- evms-2.3.2a/plugins/xfs/fsimxfs.c	15 Mar 2004 21:22:54 -0000	1.16
+++ evms-2.3.2b/plugins/xfs/fsimxfs.c	29 Apr 2004 19:04:50 -0000	1.17
@@ -173,6 +173,8 @@
 					options->option[i].number = MKFS_JOURNAL_VOL_INDEX;
 				} else if (!strcmp(options->option[i].name, "logsize")) {
 					options->option[i].number = MKFS_SETLOGSIZE_INDEX;
+				} else if (!strcmp(options->option[i].name, "force")) {
+					options->option[i].number = MKFS_FORCE_INDEX;
 				} else {
 					/* unknown. ignore. */
 					continue;
@@ -180,6 +182,13 @@
 			}
 
 			switch (options->option[i].number) {
+			case MKFS_FORCE_INDEX:
+				if (options->option[i].value.b) {
+					strcpy(buffer, "-f");
+					break;
+				} else {
+					continue;
+				}
 			case MKFS_SETVOL_INDEX:
 				if (options->option[i].value.s) {
 					sprintf(buffer, "-L%s",
@@ -262,15 +271,19 @@
 		waitpid(pidm, &status, 0);
 		if (WIFEXITED(status)) {
 			bytes_read = read(fds2[0], buffer, MAX_USER_MESSAGE_LEN);
-			if (bytes_read > 0) {
-				LOG_DETAILS("mkfs output: \n%s",buffer);
-				memset(buffer, 0, bytes_read);
-			}
 			/* Get mkfs.xfs exit code */
 			rc = WEXITSTATUS(status);
 			if (rc == 0) {
+				if (bytes_read > 0) {
+					LOG_DETAILS("mkfs output: \n%s",buffer);
+					memset(buffer, 0, bytes_read);
+				}
 				LOG_DETAILS("mkfs.xfs completed with exit code %d \n", status);
 			} else {
+				if (bytes_read > 0) {
+					MESSAGE("mkfs output: \n%s", buffer);
+					memset(buffer, 0, bytes_read);
+				}
 				LOG_ERROR("mkfs.xfs completed with exit code %d \n", status);
 			}
 		} else {
@@ -279,7 +292,7 @@
 	} else {
 		rc = EIO;
 	}
-        
+
 	close(fds2[0]);
 	close(fds2[1]);
 
@@ -447,7 +460,7 @@
 
 /**
  * xfs_swap_superblock
- * 
+ *
  * Endian swap a XFS superblock
  **/
 static void xfs_swap_superblock(xfs_sb_t * sblk)
